summaryrefslogtreecommitdiffstats
path: root/ksysv/ksvmiscconfig.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'ksysv/ksvmiscconfig.cpp')
-rw-r--r--ksysv/ksvmiscconfig.cpp8
1 files changed, 4 insertions, 4 deletions
diff --git a/ksysv/ksvmiscconfig.cpp b/ksysv/ksvmiscconfig.cpp
index a3c27ac..69b596a 100644
--- a/ksysv/ksvmiscconfig.cpp
+++ b/ksysv/ksvmiscconfig.cpp
@@ -31,11 +31,11 @@
#include <kdialog.h>
/*
* Constructs a KSVMiscConfig which is a child of 'parent', with the
* name 'name' and widget flags set to 'f'
*/
-KSVMiscConfig::KSVMiscConfig( TQWidget* parent, const char* name, WFlags fl )
- : MiscConfiguration( parent, name, fl )
+KSVMiscConfig::KSVMiscConfig( TQWidget* tqparent, const char* name, WFlags fl )
+ : MiscConfiguration( tqparent, name, fl )
{
mSpacer->setFixedHeight (KDialog::spacingHint());
@@ -57,7 +57,7 @@ void KSVMiscConfig::slotChanged()
*/
KSVMiscConfig::~KSVMiscConfig()
{
- // no need to delete child widgets, Qt does it all for us
+ // no need to delete child widgets, TQt does it all for us
}
#include "ksvmiscconfig.moc"
@@ -31,11 +31,11 @@
#include <kdialog.h>
/*
- * Constructs a KSVMiscConfig which is a child of 'parent', with the
+ * Constructs a KSVMiscConfig which is a child of 'tqparent', with the
* name 'name' and widget flags set to 'f'
*/